@@ -51,7 +51,7 @@ exports.ngVersions = function() {
     });
 
   //match the future version of AngularJS that is set in the package.json file
-  return expandVersions(sortVersionsNatrually(versions), exports.ngCurrentVersion().full);
+  return expandVersions(sortVersionsNaturally(versions), exports.ngCurrentVersion().full);
 
   function expandVersions(versions, latestVersion) {
     var RC_VERSION = /rc\d/;
@@ -87,7 +87,7 @@ exports.ngVersions = function() {
     return expanded;
   };
 
-  function sortVersionsNatrually(versions) {
+  function sortVersionsNaturally(versions) {
     var versionMap = {},
         NON_RC_RELEASE_NUMBER = 999;
     for(var i = versions.length - 1; i >= 0; i--) {
@@ -1113,14 +1113,25 @@ function scenarios(docs){
 function writeProtractorTest(doc){
   var lines = [];
   lines.push('describe("' + doc.section + '/' + doc.id + '", function() {');
-  lines.push('  beforeEach(function() {');
-  lines.push('    browser.get("index-nocache.html#!/' + doc.section + '/' + doc.id + '");');
-  lines.push('  });');
+  lines.push('  describe("angular+jqLite", function() {')
+  lines.push('    beforeEach(function() {');
+  lines.push('      browser.get("index-nocache.html#!/' + doc.section + '/' + doc.id + '");');
+  lines.push('    });');
   lines.push('');
   doc.protractorTests.forEach(function(test){
-    lines.push(indentCode(trim(test), 2));
+    lines.push(indentCode(trim(test), 4));
     lines.push('');
   });
+  lines.push('  });');
+  lines.push('  describe("angular+jQuery", function() {')
+  lines.push('    beforeEach(function() {');
+  lines.push('      browser.get("index-jq-nocache.html#!/' + doc.section + '/' + doc.id + '");');
+  lines.push('    });');
+  doc.protractorTests.forEach(function(test){
+    lines.push(indentCode(trim(test), 4));
+    lines.push('');
+  });
+  lines.push('  });');
   lines.push('});');
   lines.push('');
   return lines.join('\n');
