@@ -111,9 +111,6 @@ docsApp.serviceFactory.docsSearch = ['$rootScope','lunrSearch', 'NG_PAGES',
     angular.forEach(index.search(q), function(result) {
       var item = NG_PAGES[result.ref];
       var section = item.section;
-      if(section == 'cookbook') {
-        section = 'tutorial';
-      }
       results[section] = results[section] || [];
       if(results[section].length < 15) {
         results[section].push(item);
@@ -145,11 +142,19 @@ docsApp.directive.docsSearchInput = ['$document',function($document) {
     var ESCAPE_KEY_KEYCODE = 27,
         FORWARD_SLASH_KEYCODE = 191;
     angular.element($document[0].body).bind('keydown', function(event) {
-      var input = element[0];
-      if(event.keyCode == FORWARD_SLASH_KEYCODE && document.activeElement != input) {
-        event.stopPropagation();
-        event.preventDefault();
-        input.focus();
+      if(event.keyCode == FORWARD_SLASH_KEYCODE && document.activeElement) {
+        var activeElement = document.activeElement;
+        var activeTagName = activeElement.nodeName.toLowerCase();
+        var hasInputFocus = activeTagName == 'input'  || activeTagName == 'select' ||
+                            activeTagName == 'option' || activeTagName == 'textarea' ||
+                            activeElement.hasAttribute('contenteditable');
+        if(!hasInputFocus) {
+          event.stopPropagation();
+          event.preventDefault();
+
+          var input = element[0];
+          input.focus();
+        }
       }
     });
 
@@ -622,7 +627,6 @@ docsApp.serviceFactory.sections = ['NG_PAGES', function sections(NG_PAGES) {
     api: [],
     tutorial: [],
     misc: [],
-    cookbook: [],
     error: [],
     getPage: function(sectionId, partialId) {
       var pages = sections[sectionId];
@@ -667,7 +671,7 @@ docsApp.controller.DocsController = function($scope, $rootScope, $location, $win
     }
   };
   var OFFLINE_COOKIE_NAME = 'ng-offline',
-      DOCS_PATH = /^\/(api)|(guide)|(cookbook)|(misc)|(tutorial)|(error)/,
+      DOCS_PATH = /^\/(api)|(guide)|(misc)|(tutorial)|(error)/,
       INDEX_PATH = /^(\/|\/index[^\.]*.html)$/,
       GLOBALS = /^angular\.([^\.]+)$/,
       ERROR = /^([a-zA-Z0-9_$]+:)?([a-zA-Z0-9_$]+)$/,
@@ -729,7 +733,6 @@ docsApp.controller.DocsController = function($scope, $rootScope, $location, $win
     guide: 'Developer Guide',
     misc: 'Miscellaneous',
     tutorial: 'Tutorial',
-    cookbook: 'Examples',
     error: 'Error Reference'
   };
 
